<?php

/**
 * Execute a MySQL query and return the result in JSON format.
 *
 * @param mysqli $conn The MySQLi connection object.
 * @param string $pure_query The SQL query to execute.
 * @return string JSON encoded result set or error message.
 */
function mysql_execute($conn, $pure_query) {
    $result = $conn->query($pure_query);
    
    if ($result) {
        $data = [];
        while ($row = $result->fetch_assoc()) {
            $data[] = $row;
        }
        return json_encode($data);
    } else {
        return json_encode(['error' => $conn->error]);
    }
}

/**
 * Sanitize user input to prevent SQL injection.
 *
 * @param mysqli $conn The MySQLi connection object.
 * @param string $input The user input to sanitize.
 * @return string The sanitized input.
 */
function sanitize_input($conn, $input) {
    return htmlspecialchars($conn->real_escape_string($input));
}

/**
 * Redirect to a specified URL.
 *
 * @param string $url The URL to redirect to.
 */
function redirect($url) {
    header("Location: $url");
    exit();
}

/**
 * Check if a user is logged in based on session data.
 *
 * @return bool True if logged in, false otherwise.
 */
function is_logged_in() {
    return isset($_SESSION['user_id']);
}

/**
 * Start a secure session.
 */
function start_session() {
    if (session_status() === PHP_SESSION_NONE) {
        session_start();
        session_regenerate_id(true);
    }
}

/**
 * Hash a password using bcrypt.
 *
 * @param string $password The password to hash.
 * @return string The hashed password.
 */
function hash_password($password) {
    return password_hash($password, PASSWORD_BCRYPT);
}

/**
 * Verify a password against a hash.
 *
 * @param string $password The password to verify.
 * @param string $hash The hash to verify against.
 * @return bool True if the password matches, false otherwise.
 */
function verify_password($password, $hash) {
    return password_verify($password, $hash);
}

/**
 * Generate a random token for CSRF protection or other uses.
 *
 * @param int $length The length of the token.
 * @return string The generated token.
 */
function generate_token($length = 32) {
    return bin2hex(random_bytes($length));
}

/**
 * Get a value from the POST request with optional sanitization.
 *
 * @param string $key The key of the POST parameter.
 * @param bool $sanitize Whether to sanitize the value.
 * @return mixed The value or null if not set.
 */
function post($key, $sanitize = true) {
    return isset($_POST[$key]) ? ($sanitize ? htmlspecialchars($_POST[$key]) : $_POST[$key]) : null;
}

/**
 * Get a value from the GET request with optional sanitization.
 *
 * @param string $key The key of the GET parameter.
 * @param bool $sanitize Whether to sanitize the value.
 * @return mixed The value or null if not set.
 */
function get($key, $sanitize = true) {
    return isset($_GET[$key]) ? ($sanitize ? htmlspecialchars($_GET[$key]) : $_GET[$key]) : null;
}

/**
 * Debug a variable by outputting its contents in a readable format.
 *
 * @param mixed $variable The variable to debug.
 */
function debug($variable) {
    echo '<pre>';
    var_dump($variable);
    echo '</pre>';
    exit();
}

/**
 * Get the current URL of the page.
 *
 * @return string The current URL.
 */
function current_url() {
    $protocol = (!empty($_SERVER['HTTPS']) && $_SERVER['HTTPS'] !== 'off') ? "https://" : "http://";
    $url = $protocol . $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI'];
    return $url;
}

/**
 * Convert a timestamp to a human-readable format.
 *
 * @param int $timestamp The timestamp to convert.
 * @return string The formatted date/time.
 */
function human_readable_time($timestamp) {
    return date('Y-m-d H:i:s', $timestamp);
}


function send_sms_to($remotePost,$phone,$message){
    $verificationCodeSent = $remotePost->SendCustomMessage($phone,$message);
    if ($verificationCodeSent > 2000) {
        // Return a success response if the code is sent successfully
        $response = array("success" => true, "message" => "پیام با موفقیت ارسال شد.");
        echo json_encode($response);
    } else {
        // Return an error response if there was an issue sending the code
        $response = array("success" => false, "message" => "خطایی در ارسال پیام رخ داده است. لطفاً دوباره تلاش کنید.");
        echo json_encode($response);
    }
}
?>
